Struct aws_sdk_machinelearning::client::fluent_builders::CreateDataSourceFromRDS [−][src]
pub struct CreateDataSourceFromRDS<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to CreateDataSourceFromRDS.
Creates a DataSource object from an Amazon Relational Database Service (Amazon RDS). A DataSource references data that can be used to perform CreateMLModel, CreateEvaluation, or CreateBatchPrediction operations.
CreateDataSourceFromRDS is an asynchronous operation. In response to CreateDataSourceFromRDS, Amazon Machine Learning (Amazon ML) immediately returns and sets the DataSource status to PENDING. After the DataSource is created and ready for use, Amazon ML sets the Status parameter to COMPLETED. DataSource in the COMPLETED or PENDING state can be used only to perform >CreateMLModel>, CreateEvaluation, or CreateBatchPrediction operations.
If Amazon ML cannot accept the input source, it sets the Status parameter to FAILED and includes an error message in the Message attribute of the GetDataSource operation response.
Implementations
impl<C, M, R> CreateDataSourceFromRDS<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CreateDataSourceFromRDS<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<CreateDataSourceFromRdsOutput, SdkError<CreateDataSourceFromRDSError>> where
R::Policy: SmithyRetryPolicy<CreateDataSourceFromRdsInputOperationOutputAlias, CreateDataSourceFromRdsOutput, CreateDataSourceFromRDSError, CreateDataSourceFromRdsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<CreateDataSourceFromRdsOutput, SdkError<CreateDataSourceFromRDSError>> where
R::Policy: SmithyRetryPolicy<CreateDataSourceFromRdsInputOperationOutputAlias, CreateDataSourceFromRdsOutput, CreateDataSourceFromRDSError, CreateDataSourceFromRdsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
A user-supplied ID that uniquely identifies the DataSource. Typically, an Amazon Resource Number (ARN) becomes the ID for a DataSource.
A user-supplied ID that uniquely identifies the DataSource. Typically, an Amazon Resource Number (ARN) becomes the ID for a DataSource.
A user-supplied name or description of the DataSource.
A user-supplied name or description of the DataSource.
The data specification of an Amazon RDS DataSource:
-
DatabaseInformation -
-
DatabaseName- The name of the Amazon RDS database. -
InstanceIdentifier- A unique identifier for the Amazon RDS database instance.
-
-
DatabaseCredentials - AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon RDS database.
-
ResourceRole - A role (DataPipelineDefaultResourceRole) assumed by an EC2 instance to carry out the copy task from Amazon RDS to Amazon Simple Storage Service (Amazon S3). For more information, see Role templates for data pipelines.
-
ServiceRole - A role (DataPipelineDefaultRole) assumed by the AWS Data Pipeline service to monitor the progress of the copy task from Amazon RDS to Amazon S3. For more information, see Role templates for data pipelines.
-
SecurityInfo - The security information to use to access an RDS DB instance. You need to set up appropriate ingress rules for the security entity IDs provided to allow access to the Amazon RDS instance. Specify a [
SubnetId,SecurityGroupIds] pair for a VPC-based RDS DB instance. -
SelectSqlQuery - A query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon S3 location for staging Amazon RDS data. The data retrieved from Amazon RDS using
SelectSqlQueryis stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The data specification of an Amazon RDS DataSource:
-
DatabaseInformation -
-
DatabaseName- The name of the Amazon RDS database. -
InstanceIdentifier- A unique identifier for the Amazon RDS database instance.
-
-
DatabaseCredentials - AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon RDS database.
-
ResourceRole - A role (DataPipelineDefaultResourceRole) assumed by an EC2 instance to carry out the copy task from Amazon RDS to Amazon Simple Storage Service (Amazon S3). For more information, see Role templates for data pipelines.
-
ServiceRole - A role (DataPipelineDefaultRole) assumed by the AWS Data Pipeline service to monitor the progress of the copy task from Amazon RDS to Amazon S3. For more information, see Role templates for data pipelines.
-
SecurityInfo - The security information to use to access an RDS DB instance. You need to set up appropriate ingress rules for the security entity IDs provided to allow access to the Amazon RDS instance. Specify a [
SubnetId,SecurityGroupIds] pair for a VPC-based RDS DB instance. -
SelectSqlQuery - A query that is used to retrieve the observation data for the
Datasource. -
S3StagingLocation - The Amazon S3 location for staging Amazon RDS data. The data retrieved from Amazon RDS using
SelectSqlQueryis stored in this location. -
DataSchemaUri - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The role that Amazon ML assumes on behalf of the user to create and activate a data pipeline in the user's account and copy data using the SelectSqlQuery query from Amazon RDS to Amazon S3.
The role that Amazon ML assumes on behalf of the user to create and activate a data pipeline in the user's account and copy data using the SelectSqlQuery query from Amazon RDS to Amazon S3.
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.