Struct aws_sdk_machinelearning::client::fluent_builders::CreateDataSourceFromS3 [−][src]
pub struct CreateDataSourceFromS3<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to CreateDataSourceFromS3.
Creates a DataSource object. A DataSource references data that can be used to perform CreateMLModel, CreateEvaluation, or CreateBatchPrediction operations.
CreateDataSourceFromS3 is an asynchronous operation. In response to CreateDataSourceFromS3, Amazon Machine Learning (Amazon ML) immediately returns and sets the DataSource status to PENDING. After the DataSource has been created and is ready for use, Amazon ML sets the Status parameter to COMPLETED. DataSource in the COMPLETED or PENDING state can be used to perform only CreateMLModel, CreateEvaluation or CreateBatchPrediction operations.
If Amazon ML can't accept the input source, it sets the Status parameter to FAILED and includes an error message in the Message attribute of the GetDataSource operation response.
The observation data used in a DataSource should be ready to use; that is, it should have a consistent structure, and missing data values should be kept to a minimum. The observation data must reside in one or more .csv files in an Amazon Simple Storage Service (Amazon S3) location, along with a schema that describes the data items by name and type. The same schema must be used for all of the data files referenced by the DataSource.
After the DataSource has been created, it's ready to use in evaluations and batch predictions. If you plan to use the DataSource to train an MLModel, the DataSource also needs a recipe. A recipe describes how each input variable will be used in training an MLModel. Will the variable be included or excluded from training? Will the variable be manipulated; for example, will it be combined with another variable or will it be split apart into word combinations? The recipe provides answers to these questions.
Implementations
impl<C, M, R> CreateDataSourceFromS3<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CreateDataSourceFromS3<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<CreateDataSourceFromS3Output, SdkError<CreateDataSourceFromS3Error>> where
R::Policy: SmithyRetryPolicy<CreateDataSourceFromS3InputOperationOutputAlias, CreateDataSourceFromS3Output, CreateDataSourceFromS3Error, CreateDataSourceFromS3InputOperationRetryAlias>,
pub async fn send(
self
) -> Result<CreateDataSourceFromS3Output, SdkError<CreateDataSourceFromS3Error>> where
R::Policy: SmithyRetryPolicy<CreateDataSourceFromS3InputOperationOutputAlias, CreateDataSourceFromS3Output, CreateDataSourceFromS3Error, CreateDataSourceFromS3InputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
A user-supplied identifier that uniquely identifies the DataSource.
A user-supplied identifier that uniquely identifies the DataSource.
A user-supplied name or description of the DataSource.
A user-supplied name or description of the DataSource.
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.