Struct aws_sdk_machinelearning::client::fluent_builders::DeleteEvaluation [−][src]
pub struct DeleteEvaluation<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DeleteEvaluation.
Assigns the DELETED status to an Evaluation, rendering it unusable.
After invoking the DeleteEvaluation operation, you can use the
GetEvaluation operation to verify that the status of the Evaluation changed to DELETED.
Caution: The results of the DeleteEvaluation operation are irreversible.
Implementations
impl<C, M, R> DeleteEvaluation<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DeleteEvaluation<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DeleteEvaluationOutput, SdkError<DeleteEvaluationError>> where
R::Policy: SmithyRetryPolicy<DeleteEvaluationInputOperationOutputAlias, DeleteEvaluationOutput, DeleteEvaluationError, DeleteEvaluationInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DeleteEvaluationOutput, SdkError<DeleteEvaluationError>> where
R::Policy: SmithyRetryPolicy<DeleteEvaluationInputOperationOutputAlias, DeleteEvaluationOutput, DeleteEvaluationError, DeleteEvaluationInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
A user-supplied ID that uniquely identifies the Evaluation to delete.
A user-supplied ID that uniquely identifies the Evaluation to delete.