Struct aws_sdk_machinelearning::client::fluent_builders::DescribeBatchPredictions [−][src]
pub struct DescribeBatchPredictions<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DescribeBatchPredictions.
Returns a list of BatchPrediction operations that match the search criteria in the request.
Implementations
impl<C, M, R> DescribeBatchPredictions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribeBatchPredictions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribeBatchPredictionsOutput, SdkError<DescribeBatchPredictionsError>> where
R::Policy: SmithyRetryPolicy<DescribeBatchPredictionsInputOperationOutputAlias, DescribeBatchPredictionsOutput, DescribeBatchPredictionsError, DescribeBatchPredictionsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribeBatchPredictionsOutput, SdkError<DescribeBatchPredictionsError>> where
R::Policy: SmithyRetryPolicy<DescribeBatchPredictionsInputOperationOutputAlias, DescribeBatchPredictionsOutput, DescribeBatchPredictionsError, DescribeBatchPredictionsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Use one of the following variables to filter a list of BatchPrediction:
-
CreatedAt- Sets the search criteria to theBatchPredictioncreation date. -
Status- Sets the search criteria to theBatchPredictionstatus. -
Name- Sets the search criteria to the contents of theBatchPredictionName. -
IAMUser- Sets the search criteria to the user account that invoked theBatchPredictioncreation. -
MLModelId- Sets the search criteria to theMLModelused in theBatchPrediction. -
DataSourceId- Sets the search criteria to theDataSourceused in theBatchPrediction. -
DataURI- Sets the search criteria to the data file(s) used in theBatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
Use one of the following variables to filter a list of BatchPrediction:
-
CreatedAt- Sets the search criteria to theBatchPredictioncreation date. -
Status- Sets the search criteria to theBatchPredictionstatus. -
Name- Sets the search criteria to the contents of theBatchPredictionName. -
IAMUser- Sets the search criteria to the user account that invoked theBatchPredictioncreation. -
MLModelId- Sets the search criteria to theMLModelused in theBatchPrediction. -
DataSourceId- Sets the search criteria to theDataSourceused in theBatchPrediction. -
DataURI- Sets the search criteria to the data file(s) used in theBatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
The equal to operator. The BatchPrediction results will have
FilterVariable values that exactly match the value specified with EQ.
The equal to operator. The BatchPrediction results will have
FilterVariable values that exactly match the value specified with EQ.
The greater than operator. The BatchPrediction results will
have FilterVariable values that are greater than the value specified with GT.
The greater than operator. The BatchPrediction results will
have FilterVariable values that are greater than the value specified with GT.
The less than operator. The BatchPrediction results will
have FilterVariable values that are less than the value specified with LT.
The less than operator. The BatchPrediction results will
have FilterVariable values that are less than the value specified with LT.
The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE.
The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE.
The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE.
The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE.
The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE.
The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE.
A string that is found at the beginning of a variable, such as Name or Id.
For example, a Batch Prediction operation could have the Name
2014-09-09-HolidayGiftMailer. To search for
this BatchPrediction, select Name for the FilterVariable and any of the following strings for the
Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A string that is found at the beginning of a variable, such as Name or Id.
For example, a Batch Prediction operation could have the Name
2014-09-09-HolidayGiftMailer. To search for
this BatchPrediction, select Name for the FilterVariable and any of the following strings for the
Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A two-value parameter that determines the sequence of the resulting list of MLModels.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
A two-value parameter that determines the sequence of the resulting list of MLModels.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
An ID of the page in the paginated results.
An ID of the page in the paginated results.
The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100.