Struct aws_sdk_machinelearning::client::fluent_builders::DescribeDataSources [−][src]
pub struct DescribeDataSources<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DescribeDataSources.
Returns a list of DataSource that match the search criteria in the request.
Implementations
impl<C, M, R> DescribeDataSources<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribeDataSources<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribeDataSourcesOutput, SdkError<DescribeDataSourcesError>> where
R::Policy: SmithyRetryPolicy<DescribeDataSourcesInputOperationOutputAlias, DescribeDataSourcesOutput, DescribeDataSourcesError, DescribeDataSourcesInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribeDataSourcesOutput, SdkError<DescribeDataSourcesError>> where
R::Policy: SmithyRetryPolicy<DescribeDataSourcesInputOperationOutputAlias, DescribeDataSourcesOutput, DescribeDataSourcesError, DescribeDataSourcesInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Create a paginator for this request
Paginators are used by calling send().await which returns a Stream.
Use one of the following variables to filter a list of DataSource:
-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
Use one of the following variables to filter a list of DataSource:
-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
The equal to operator. The DataSource results will have FilterVariable values that exactly match the value specified with EQ.
The equal to operator. The DataSource results will have FilterVariable values that exactly match the value specified with EQ.
The greater than operator. The DataSource results will have FilterVariable values that are greater than the value specified with GT.
The greater than operator. The DataSource results will have FilterVariable values that are greater than the value specified with GT.
The less than operator. The DataSource results will have FilterVariable values that are less than the value specified with LT.
The less than operator. The DataSource results will have FilterVariable values that are less than the value specified with LT.
The greater than or equal to operator. The DataSource results will have FilterVariable values that are greater than or equal to the value specified with GE.
The greater than or equal to operator. The DataSource results will have FilterVariable values that are greater than or equal to the value specified with GE.
The less than or equal to operator. The DataSource results will have FilterVariable values that are less than or equal to the value specified with LE.
The less than or equal to operator. The DataSource results will have FilterVariable values that are less than or equal to the value specified with LE.
The not equal to operator. The DataSource results will have FilterVariable values not equal to the value specified with NE.
The not equal to operator. The DataSource results will have FilterVariable values not equal to the value specified with NE.
A string that is found at the beginning of a variable, such as Name or Id.
For example, a DataSource could have the Name 2014-09-09-HolidayGiftMailer. To search for this DataSource, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A string that is found at the beginning of a variable, such as Name or Id.
For example, a DataSource could have the Name 2014-09-09-HolidayGiftMailer. To search for this DataSource, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A two-value parameter that determines the sequence of the resulting list of DataSource.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
A two-value parameter that determines the sequence of the resulting list of DataSource.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
The ID of the page in the paginated results.
The ID of the page in the paginated results.
The maximum number of DataSource to include in the result.