Struct aws_sdk_machinelearning::client::fluent_builders::DescribeMLModels [−][src]
pub struct DescribeMLModels<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DescribeMLModels.
Returns a list of MLModel that match the search criteria in the request.
Implementations
impl<C, M, R> DescribeMLModels<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribeMLModels<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribeMlModelsOutput, SdkError<DescribeMLModelsError>> where
R::Policy: SmithyRetryPolicy<DescribeMlModelsInputOperationOutputAlias, DescribeMlModelsOutput, DescribeMLModelsError, DescribeMlModelsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribeMlModelsOutput, SdkError<DescribeMLModelsError>> where
R::Policy: SmithyRetryPolicy<DescribeMlModelsInputOperationOutputAlias, DescribeMlModelsOutput, DescribeMLModelsError, DescribeMlModelsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Create a paginator for this request
Paginators are used by calling send().await which returns a Stream.
Use one of the following variables to filter a list of MLModel:
-
CreatedAt- Sets the search criteria toMLModelcreation date. -
Status- Sets the search criteria toMLModelstatus. -
Name- Sets the search criteria to the contents ofMLModelName. -
IAMUser- Sets the search criteria to the user account that invoked theMLModelcreation. -
TrainingDataSourceId- Sets the search criteria to theDataSourceused to train one or moreMLModel. -
RealtimeEndpointStatus- Sets the search criteria to theMLModelreal-time endpoint status. -
MLModelType- Sets the search criteria toMLModeltype: binary, regression, or multi-class. -
Algorithm- Sets the search criteria to the algorithm that theMLModeluses. -
TrainingDataURI- Sets the search criteria to the data file(s) used in training aMLModel. The URL can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.
Use one of the following variables to filter a list of MLModel:
-
CreatedAt- Sets the search criteria toMLModelcreation date. -
Status- Sets the search criteria toMLModelstatus. -
Name- Sets the search criteria to the contents ofMLModelName. -
IAMUser- Sets the search criteria to the user account that invoked theMLModelcreation. -
TrainingDataSourceId- Sets the search criteria to theDataSourceused to train one or moreMLModel. -
RealtimeEndpointStatus- Sets the search criteria to theMLModelreal-time endpoint status. -
MLModelType- Sets the search criteria toMLModeltype: binary, regression, or multi-class. -
Algorithm- Sets the search criteria to the algorithm that theMLModeluses. -
TrainingDataURI- Sets the search criteria to the data file(s) used in training aMLModel. The URL can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.
The equal to operator. The MLModel results will have FilterVariable values that exactly match the value specified with EQ.
The equal to operator. The MLModel results will have FilterVariable values that exactly match the value specified with EQ.
The greater than operator. The MLModel results will have FilterVariable values that are greater than the value specified with GT.
The greater than operator. The MLModel results will have FilterVariable values that are greater than the value specified with GT.
The less than operator. The MLModel results will have FilterVariable values that are less than the value specified with LT.
The less than operator. The MLModel results will have FilterVariable values that are less than the value specified with LT.
The greater than or equal to operator. The MLModel results will have FilterVariable values that are greater than or equal to the value specified with GE.
The greater than or equal to operator. The MLModel results will have FilterVariable values that are greater than or equal to the value specified with GE.
The less than or equal to operator. The MLModel results will have FilterVariable values that are less than or equal to the value specified with LE.
The less than or equal to operator. The MLModel results will have FilterVariable values that are less than or equal to the value specified with LE.
The not equal to operator. The MLModel results will have FilterVariable values not equal to the value specified with NE.
The not equal to operator. The MLModel results will have FilterVariable values not equal to the value specified with NE.
A string that is found at the beginning of a variable, such as Name or Id.
For example, an MLModel could have the Name 2014-09-09-HolidayGiftMailer. To search for this MLModel, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A string that is found at the beginning of a variable, such as Name or Id.
For example, an MLModel could have the Name 2014-09-09-HolidayGiftMailer. To search for this MLModel, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A two-value parameter that determines the sequence of the resulting list of MLModel.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
A two-value parameter that determines the sequence of the resulting list of MLModel.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
The ID of the page in the paginated results.
The ID of the page in the paginated results.
The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100.