Struct aws_sdk_machinelearning::client::fluent_builders::GetDataSource [−][src]
pub struct GetDataSource<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetDataSource.
Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.
GetDataSource provides results in normal or verbose format. The verbose format adds the schema description and the list of files pointed to by the DataSource to the normal format.
Implementations
impl<C, M, R> GetDataSource<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetDataSource<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<GetDataSourceOutput, SdkError<GetDataSourceError>> where
R::Policy: SmithyRetryPolicy<GetDataSourceInputOperationOutputAlias, GetDataSourceOutput, GetDataSourceError, GetDataSourceInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<GetDataSourceOutput, SdkError<GetDataSourceError>> where
R::Policy: SmithyRetryPolicy<GetDataSourceInputOperationOutputAlias, GetDataSourceOutput, GetDataSourceError, GetDataSourceInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ID assigned to the DataSource at creation.
The ID assigned to the DataSource at creation.
Specifies whether the GetDataSource operation should return DataSourceSchema.
If true, DataSourceSchema is returned.
If false, DataSourceSchema is not returned.
Specifies whether the GetDataSource operation should return DataSourceSchema.
If true, DataSourceSchema is returned.
If false, DataSourceSchema is not returned.