Struct aws_sdk_machinelearning::client::fluent_builders::GetMLModel [−][src]
pub struct GetMLModel<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetMLModel.
Returns an MLModel that includes detailed metadata, data source information, and the current status of the MLModel.
GetMLModel provides results in normal or verbose format.
Implementations
impl<C, M, R> GetMLModel<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetMLModel<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<GetMlModelOutput, SdkError<GetMLModelError>> where
R::Policy: SmithyRetryPolicy<GetMlModelInputOperationOutputAlias, GetMlModelOutput, GetMLModelError, GetMlModelInputOperationRetryAlias>,
pub async fn send(self) -> Result<GetMlModelOutput, SdkError<GetMLModelError>> where
R::Policy: SmithyRetryPolicy<GetMlModelInputOperationOutputAlias, GetMlModelOutput, GetMLModelError, GetMlModelInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ID assigned to the MLModel at creation.
The ID assigned to the MLModel at creation.
Specifies whether the GetMLModel operation should return Recipe.
If true, Recipe is returned.
If false, Recipe is not returned.
Specifies whether the GetMLModel operation should return Recipe.
If true, Recipe is returned.
If false, Recipe is not returned.