Struct aws_sdk_machinelearning::client::fluent_builders::UpdateMLModel [−][src]
pub struct UpdateMLModel<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateMLModel.
Updates the MLModelName and the ScoreThreshold of an MLModel.
You can use the GetMLModel operation to view the contents of the updated data element.
Implementations
impl<C, M, R> UpdateMLModel<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateMLModel<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateMlModelOutput, SdkError<UpdateMLModelError>> where
R::Policy: SmithyRetryPolicy<UpdateMlModelInputOperationOutputAlias, UpdateMlModelOutput, UpdateMLModelError, UpdateMlModelInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateMlModelOutput, SdkError<UpdateMLModelError>> where
R::Policy: SmithyRetryPolicy<UpdateMlModelInputOperationOutputAlias, UpdateMlModelOutput, UpdateMLModelError, UpdateMlModelInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ID assigned to the MLModel during creation.
The ID assigned to the MLModel during creation.
A user-supplied name or description of the MLModel.
A user-supplied name or description of the MLModel.
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.