Struct aws_sdk_machinelearning::client::Client [−][src]
pub struct Client<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Client for Amazon Machine Learning
Client for invoking operations on Amazon Machine Learning. Each operation on Amazon Machine Learning is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Examples
Constructing a client and invoking an operation
// create a shared configuration. This can be used & shared between multiple service clients.
let shared_config = aws_config::load_from_env().await;
let client = aws_sdk_machinelearning::Client::new(&shared_config);
// invoke an operation
/* let rsp = client
.<operation_name>().
.<param>("some value")
.send().await; */Constructing a client with custom configuration
use aws_config::RetryConfig;
let shared_config = aws_config::load_from_env().await;
let config = aws_sdk_machinelearning::config::Builder::from(&shared_config)
.retry_config(RetryConfig::disabled())
.build();
let client = aws_sdk_machinelearning::Client::from_conf(config);Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AddTags operation.
See AddTags for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateBatchPrediction operation.
See CreateBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromRDS operation.
See CreateDataSourceFromRDS for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromRedshift operation.
See CreateDataSourceFromRedshift for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromS3 operation.
See CreateDataSourceFromS3 for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateEvaluation operation.
See CreateEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateMLModel operation.
See CreateMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateRealtimeEndpoint operation.
See CreateRealtimeEndpoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBatchPrediction operation.
See DeleteBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDataSource operation.
See DeleteDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteEvaluation operation.
See DeleteEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteMLModel operation.
See DeleteMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteRealtimeEndpoint operation.
See DeleteRealtimeEndpoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteTags operation.
See DeleteTags for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeBatchPredictions operation.
See DescribeBatchPredictions for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the DescribeDataSources operation.
See DescribeDataSources for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the DescribeEvaluations operation.
See DescribeEvaluations for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the DescribeMLModels operation.
See DescribeMLModels for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the DescribeTags operation.
See DescribeTags for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBatchPrediction operation.
See GetBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the GetDataSource operation.
See GetDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the GetEvaluation operation.
See GetEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the GetMLModel operation.
See GetMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the Predict operation.
See Predict for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateBatchPrediction operation.
See UpdateBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDataSource operation.
See UpdateDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateEvaluation operation.
See UpdateEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateMLModel operation.
See UpdateMLModel for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.