Struct aws_sdk_machinelearning::error::IdempotentParameterMismatchException [−][src]
#[non_exhaustive]pub struct IdempotentParameterMismatchException {
pub message: Option<String>,
pub code: i32,
}Expand description
A second request to use or change an object was not allowed. This can result from retrying a request using a parameter that was not present in the original request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>code: i32Implementations
Creates a new builder-style object to manufacture IdempotentParameterMismatchException