Struct aws_sdk_machinelearning::input::create_batch_prediction_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateBatchPredictionInput
Implementations
A user-supplied ID that uniquely identifies the BatchPrediction.
A user-supplied ID that uniquely identifies the BatchPrediction.
A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set.
A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set.
The ID of the MLModel that will generate predictions for the group of observations.
The ID of the MLModel that will generate predictions for the group of observations.
The ID of the DataSource that points to the group of observations to predict.
The ID of the DataSource that points to the group of observations to predict.
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the Amazon Machine Learning Developer Guide.
Consumes the builder and constructs a CreateBatchPredictionInput