Struct aws_sdk_machinelearning::input::create_data_source_from_s3_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateDataSourceFromS3Input
Implementations
A user-supplied identifier that uniquely identifies the DataSource.
A user-supplied identifier that uniquely identifies the DataSource.
A user-supplied name or description of the DataSource.
A user-supplied name or description of the DataSource.
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by
a DataSource. Amazon ML uses the statistics internally during MLModel training.
This parameter must be set to true if the DataSource needs to be used for MLModel training.
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by
a DataSource. Amazon ML uses the statistics internally during MLModel training.
This parameter must be set to true if the DataSource needs to be used for MLModel training.
Consumes the builder and constructs a CreateDataSourceFromS3Input