Struct aws_sdk_machinelearning::input::create_evaluation_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateEvaluationInput
Implementations
A user-supplied ID that uniquely identifies the Evaluation.
A user-supplied ID that uniquely identifies the Evaluation.
A user-supplied name or description of the Evaluation.
A user-supplied name or description of the Evaluation.
The ID of the MLModel to evaluate.
The schema used in creating the MLModel must match the schema of the DataSource used in the Evaluation.
The ID of the MLModel to evaluate.
The schema used in creating the MLModel must match the schema of the DataSource used in the Evaluation.
The ID of the DataSource for the evaluation. The schema of the DataSource must match the schema used to create the MLModel.
The ID of the DataSource for the evaluation. The schema of the DataSource must match the schema used to create the MLModel.
Consumes the builder and constructs a CreateEvaluationInput