Struct aws_sdk_machinelearning::input::describe_evaluations_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribeEvaluationsInput
Implementations
Use one of the following variable to filter a list of Evaluation objects:
-
CreatedAt- Sets the search criteria to theEvaluationcreation date. -
Status- Sets the search criteria to theEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked anEvaluation. -
MLModelId- Sets the search criteria to theMLModelthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused inEvaluation. -
DataUri- Sets the search criteria to the data file(s) used inEvaluation. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
Use one of the following variable to filter a list of Evaluation objects:
-
CreatedAt- Sets the search criteria to theEvaluationcreation date. -
Status- Sets the search criteria to theEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked anEvaluation. -
MLModelId- Sets the search criteria to theMLModelthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused inEvaluation. -
DataUri- Sets the search criteria to the data file(s) used inEvaluation. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ.
The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ.
The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT.
The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT.
The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT.
The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT.
The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE.
The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE.
The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE.
The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE.
The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE.
The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE.
A string that is found at the beginning of a variable, such as Name or Id.
For example, an Evaluation could have the Name 2014-09-09-HolidayGiftMailer. To search for this Evaluation, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A string that is found at the beginning of a variable, such as Name or Id.
For example, an Evaluation could have the Name 2014-09-09-HolidayGiftMailer. To search for this Evaluation, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A two-value parameter that determines the sequence of the resulting list of Evaluation.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
A two-value parameter that determines the sequence of the resulting list of Evaluation.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
The ID of the page in the paginated results.
The ID of the page in the paginated results.
The maximum number of Evaluation to include in the result.
The maximum number of Evaluation to include in the result.
Consumes the builder and constructs a DescribeEvaluationsInput