Struct aws_sdk_machinelearning::input::CreateDataSourceFromS3Input [−][src]
#[non_exhaustive]pub struct CreateDataSourceFromS3Input {
pub data_source_id: Option<String>,
pub data_source_name: Option<String>,
pub data_spec: Option<S3DataSpec>,
pub compute_statistics: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source_id: Option<String>A user-supplied identifier that uniquely identifies the DataSource.
data_source_name: Option<String>A user-supplied name or description of the DataSource.
data_spec: Option<S3DataSpec>The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
compute_statistics: boolThe compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateDataSourceFromS3, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateDataSourceFromS3, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateDataSourceFromS3>
Creates a new builder-style object to manufacture CreateDataSourceFromS3Input
A user-supplied identifier that uniquely identifies the DataSource.
A user-supplied name or description of the DataSource.
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample -
"{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.