Struct aws_sdk_machinelearning::input::CreateEvaluationInput [−][src]
#[non_exhaustive]pub struct CreateEvaluationInput {
pub evaluation_id: Option<String>,
pub evaluation_name: Option<String>,
pub ml_model_id: Option<String>,
pub evaluation_data_source_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation_id: Option<String>A user-supplied ID that uniquely identifies the Evaluation.
evaluation_name: Option<String>A user-supplied name or description of the Evaluation.
ml_model_id: Option<String>The ID of the MLModel to evaluate.
The schema used in creating the MLModel must match the schema of the DataSource used in the Evaluation.
evaluation_data_source_id: Option<String>The ID of the DataSource for the evaluation. The schema of the DataSource must match the schema used to create the MLModel.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateEvaluation, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateEvaluation, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateEvaluation>
Creates a new builder-style object to manufacture CreateEvaluationInput
A user-supplied ID that uniquely identifies the Evaluation.
A user-supplied name or description of the Evaluation.
The ID of the MLModel to evaluate.
The schema used in creating the MLModel must match the schema of the DataSource used in the Evaluation.
The ID of the DataSource for the evaluation. The schema of the DataSource must match the schema used to create the MLModel.