Struct aws_sdk_machinelearning::input::DescribeBatchPredictionsInput [−][src]
#[non_exhaustive]pub struct DescribeBatchPredictionsInput {
pub filter_variable: Option<BatchPredictionFilterVariable>,
pub eq: Option<String>,
pub gt: Option<String>,
pub lt: Option<String>,
pub ge: Option<String>,
pub le: Option<String>,
pub ne: Option<String>,
pub prefix: Option<String>,
pub sort_order: Option<SortOrder>,
pub next_token: Option<String>,
pub limit: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter_variable: Option<BatchPredictionFilterVariable>Use one of the following variables to filter a list of BatchPrediction:
-
CreatedAt- Sets the search criteria to theBatchPredictioncreation date. -
Status- Sets the search criteria to theBatchPredictionstatus. -
Name- Sets the search criteria to the contents of theBatchPredictionName. -
IAMUser- Sets the search criteria to the user account that invoked theBatchPredictioncreation. -
MLModelId- Sets the search criteria to theMLModelused in theBatchPrediction. -
DataSourceId- Sets the search criteria to theDataSourceused in theBatchPrediction. -
DataURI- Sets the search criteria to the data file(s) used in theBatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
eq: Option<String>The equal to operator. The BatchPrediction results will have FilterVariable values that exactly match the value specified with EQ.
gt: Option<String>The greater than operator. The BatchPrediction results will have FilterVariable values that are greater than the value specified with GT.
lt: Option<String>The less than operator. The BatchPrediction results will have FilterVariable values that are less than the value specified with LT.
ge: Option<String>The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE.
le: Option<String>The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE.
ne: Option<String>The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE.
prefix: Option<String>A string that is found at the beginning of a variable, such as Name or Id.
For example, a Batch Prediction operation could have the Name 2014-09-09-HolidayGiftMailer. To search for this BatchPrediction, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
sort_order: Option<SortOrder>A two-value parameter that determines the sequence of the resulting list of MLModels.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
next_token: Option<String>An ID of the page in the paginated results.
limit: Option<i32>The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeBatchPredictions, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeBatchPredictions, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<DescribeBatchPredictions>
Creates a new builder-style object to manufacture DescribeBatchPredictionsInput
Use one of the following variables to filter a list of BatchPrediction:
-
CreatedAt- Sets the search criteria to theBatchPredictioncreation date. -
Status- Sets the search criteria to theBatchPredictionstatus. -
Name- Sets the search criteria to the contents of theBatchPredictionName. -
IAMUser- Sets the search criteria to the user account that invoked theBatchPredictioncreation. -
MLModelId- Sets the search criteria to theMLModelused in theBatchPrediction. -
DataSourceId- Sets the search criteria to theDataSourceused in theBatchPrediction. -
DataURI- Sets the search criteria to the data file(s) used in theBatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
The equal to operator. The BatchPrediction results will have FilterVariable values that exactly match the value specified with EQ.
The greater than operator. The BatchPrediction results will have FilterVariable values that are greater than the value specified with GT.
The less than operator. The BatchPrediction results will have FilterVariable values that are less than the value specified with LT.
The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE.
The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE.
The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE.
A string that is found at the beginning of a variable, such as Name or Id.
For example, a Batch Prediction operation could have the Name 2014-09-09-HolidayGiftMailer. To search for this BatchPrediction, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
A two-value parameter that determines the sequence of the resulting list of MLModels.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
An ID of the page in the paginated results.