#[non_exhaustive]pub struct DescribeEvaluationsInput { /* private fields */ }Implementations
sourceimpl DescribeEvaluationsInput
impl DescribeEvaluationsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeEvaluations, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeEvaluations, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeEvaluations>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeEvaluationsInput.
sourceimpl DescribeEvaluationsInput
impl DescribeEvaluationsInput
sourcepub fn filter_variable(&self) -> Option<&EvaluationFilterVariable>
pub fn filter_variable(&self) -> Option<&EvaluationFilterVariable>
Use one of the following variable to filter a list of Evaluation objects:
-
CreatedAt- Sets the search criteria to theEvaluationcreation date. -
Status- Sets the search criteria to theEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked anEvaluation. -
MLModelId- Sets the search criteria to theMLModelthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused inEvaluation. -
DataUri- Sets the search criteria to the data file(s) used inEvaluation. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
sourcepub fn eq(&self) -> Option<&str>
pub fn eq(&self) -> Option<&str>
The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ.
sourcepub fn gt(&self) -> Option<&str>
pub fn gt(&self) -> Option<&str>
The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT.
sourcepub fn lt(&self) -> Option<&str>
pub fn lt(&self) -> Option<&str>
The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT.
sourcepub fn ge(&self) -> Option<&str>
pub fn ge(&self) -> Option<&str>
The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE.
sourcepub fn le(&self) -> Option<&str>
pub fn le(&self) -> Option<&str>
The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE.
sourcepub fn ne(&self) -> Option<&str>
pub fn ne(&self) -> Option<&str>
The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE.
sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
A string that is found at the beginning of a variable, such as Name or Id.
For example, an Evaluation could have the Name 2014-09-09-HolidayGiftMailer. To search for this Evaluation, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
sourcepub fn sort_order(&self) -> Option<&SortOrder>
pub fn sort_order(&self) -> Option<&SortOrder>
A two-value parameter that determines the sequence of the resulting list of Evaluation.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The ID of the page in the paginated results.