Struct aws_sdk_machinelearning::input::UpdateMlModelInput
source · #[non_exhaustive]pub struct UpdateMlModelInput { /* private fields */ }Implementations
sourceimpl UpdateMlModelInput
impl UpdateMlModelInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateMLModel, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateMLModel, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<UpdateMLModel>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateMlModelInput.
sourceimpl UpdateMlModelInput
impl UpdateMlModelInput
sourcepub fn ml_model_id(&self) -> Option<&str>
pub fn ml_model_id(&self) -> Option<&str>
The ID assigned to the MLModel during creation.
sourcepub fn ml_model_name(&self) -> Option<&str>
pub fn ml_model_name(&self) -> Option<&str>
A user-supplied name or description of the MLModel.
sourcepub fn score_threshold(&self) -> Option<f32>
pub fn score_threshold(&self) -> Option<f32>
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.