Struct aws_sdk_machinelearning::input::update_evaluation_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateEvaluationInput
Implementations
The ID assigned to the Evaluation during creation.
The ID assigned to the Evaluation during creation.
A new user-supplied name or description of the Evaluation that will replace the current content.
A new user-supplied name or description of the Evaluation that will replace the current content.
Consumes the builder and constructs a UpdateEvaluationInput