pub struct Builder { /* private fields */ }Expand description
A builder for UpdateMlModelInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn ml_model_id(self, input: impl Into<String>) -> Self
pub fn ml_model_id(self, input: impl Into<String>) -> Self
The ID assigned to the MLModel during creation.
sourcepub fn set_ml_model_id(self, input: Option<String>) -> Self
pub fn set_ml_model_id(self, input: Option<String>) -> Self
The ID assigned to the MLModel during creation.
sourcepub fn ml_model_name(self, input: impl Into<String>) -> Self
pub fn ml_model_name(self, input: impl Into<String>) -> Self
A user-supplied name or description of the MLModel.
sourcepub fn set_ml_model_name(self, input: Option<String>) -> Self
pub fn set_ml_model_name(self, input: Option<String>) -> Self
A user-supplied name or description of the MLModel.
sourcepub fn score_threshold(self, input: f32) -> Self
pub fn score_threshold(self, input: f32) -> Self
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
sourcepub fn set_score_threshold(self, input: Option<f32>) -> Self
pub fn set_score_threshold(self, input: Option<f32>) -> Self
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
sourcepub fn build(self) -> Result<UpdateMlModelInput, BuildError>
pub fn build(self) -> Result<UpdateMlModelInput, BuildError>
Consumes the builder and constructs a UpdateMlModelInput.