Struct aws_sdk_machinelearning::model::batch_prediction::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchPrediction
Implementations
The ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
The ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
The ID of the MLModel that generated predictions for the BatchPrediction request.
The ID of the MLModel that generated predictions for the BatchPrediction request.
The ID of the DataSource that points to the group of observations to predict.
The ID of the DataSource that points to the group of observations to predict.
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The time that the BatchPrediction was created. The time is expressed in epoch time.
The time that the BatchPrediction was created. The time is expressed in epoch time.
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
A user-supplied name or description of the BatchPrediction.
A user-supplied name or description of the BatchPrediction.
The status of the BatchPrediction. This element can have one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate predictions for a batch of observations. -
INPROGRESS- The process is underway. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
The status of the BatchPrediction. This element can have one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate predictions for a batch of observations. -
INPROGRESS- The process is underway. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
The location of an Amazon S3 bucket or directory to receive the operation results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
The location of an Amazon S3 bucket or directory to receive the operation results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
A description of the most recent details about processing the batch prediction request.
A description of the most recent details about processing the batch prediction request.
Long integer type that is a 64-bit signed number.
Long integer type that is a 64-bit signed number.
A timestamp represented in epoch time.
A timestamp represented in epoch time.
A timestamp represented in epoch time.
A timestamp represented in epoch time.
Long integer type that is a 64-bit signed number.
Long integer type that is a 64-bit signed number.
Long integer type that is a 64-bit signed number.
Long integer type that is a 64-bit signed number.
Consumes the builder and constructs a BatchPrediction