Enum aws_sdk_machinelearning::model::DataSourceFilterVariable [−][src]
#[non_exhaustive]
pub enum DataSourceFilterVariable {
CreatedAt,
DataUri,
IamUser,
LastUpdatedAt,
Name,
Status,
Unknown(String),
}Expand description
A list of the variables to use in searching or filtering DataSource.
-
CreatedAt- Sets the search criteria toDataSourcecreation date. -
Status- Sets the search criteria toDataSourcestatus. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
Note:
The variable names should match the variable names in the DataSource.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CreatedAt
DataUri
IamUser
LastUpdatedAt
Name
Status
Unknown(String)
Tuple Fields
0: StringUnknown contains new variants that have been added since this code was generated.
Implementations