#[non_exhaustive]
pub enum EvaluationFilterVariable {
CreatedAt,
DatasourceId,
DataUri,
IamUser,
LastUpdatedAt,
MlModelId,
Name,
Status,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against EvaluationFilterVariable, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let evaluationfiltervariable = unimplemented!();
match evaluationfiltervariable {
EvaluationFilterVariable::CreatedAt => { /* ... */ },
EvaluationFilterVariable::DatasourceId => { /* ... */ },
EvaluationFilterVariable::DataUri => { /* ... */ },
EvaluationFilterVariable::IamUser => { /* ... */ },
EvaluationFilterVariable::LastUpdatedAt => { /* ... */ },
EvaluationFilterVariable::MlModelId => { /* ... */ },
EvaluationFilterVariable::Name => { /* ... */ },
EvaluationFilterVariable::Status => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}
The above code demonstrates that when evaluationfiltervariable represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant EvaluationFilterVariable::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
EvaluationFilterVariable::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant EvaluationFilterVariable::NewFeature is defined.
Specifically, when evaluationfiltervariable represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on EvaluationFilterVariable::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
A list of the variables to use in searching or filtering Evaluation.
-
CreatedAt- Sets the search criteria toEvaluationcreation date. -
Status- Sets the search criteria toEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked an evaluation. -
MLModelId- Sets the search criteria to thePredictorthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused in evaluation. -
DataUri- Sets the search criteria to the data file(s) used in evaluation. The URL can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CreatedAt
DatasourceId
DataUri
IamUser
LastUpdatedAt
MlModelId
Name
Status
Unknown(UnknownVariantValue)
Unknown contains new variants that have been added since this code was generated.
Implementations