Struct aws_sdk_machinelearning::model::BatchPrediction
source · #[non_exhaustive]pub struct BatchPrediction { /* private fields */ }Expand description
Represents the output of a GetBatchPrediction operation.
The content consists of the detailed metadata, the status, and the data file information of a Batch Prediction.
Implementations
sourceimpl BatchPrediction
impl BatchPrediction
sourcepub fn batch_prediction_id(&self) -> Option<&str>
pub fn batch_prediction_id(&self) -> Option<&str>
The ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
sourcepub fn ml_model_id(&self) -> Option<&str>
pub fn ml_model_id(&self) -> Option<&str>
The ID of the MLModel that generated predictions for the BatchPrediction request.
sourcepub fn batch_prediction_data_source_id(&self) -> Option<&str>
pub fn batch_prediction_data_source_id(&self) -> Option<&str>
The ID of the DataSource that points to the group of observations to predict.
sourcepub fn input_data_location_s3(&self) -> Option<&str>
pub fn input_data_location_s3(&self) -> Option<&str>
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
sourcepub fn created_by_iam_user(&self) -> Option<&str>
pub fn created_by_iam_user(&self) -> Option<&str>
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The time that the BatchPrediction was created. The time is expressed in epoch time.
sourcepub fn last_updated_at(&self) -> Option<&DateTime>
pub fn last_updated_at(&self) -> Option<&DateTime>
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
sourcepub fn status(&self) -> Option<&EntityStatus>
pub fn status(&self) -> Option<&EntityStatus>
The status of the BatchPrediction. This element can have one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate predictions for a batch of observations. -
INPROGRESS- The process is underway. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
sourcepub fn output_uri(&self) -> Option<&str>
pub fn output_uri(&self) -> Option<&str>
The location of an Amazon S3 bucket or directory to receive the operation results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
A description of the most recent details about processing the batch prediction request.
sourcepub fn compute_time(&self) -> Option<i64>
pub fn compute_time(&self) -> Option<i64>
Long integer type that is a 64-bit signed number.
sourcepub fn finished_at(&self) -> Option<&DateTime>
pub fn finished_at(&self) -> Option<&DateTime>
A timestamp represented in epoch time.
sourcepub fn started_at(&self) -> Option<&DateTime>
pub fn started_at(&self) -> Option<&DateTime>
A timestamp represented in epoch time.
sourcepub fn total_record_count(&self) -> Option<i64>
pub fn total_record_count(&self) -> Option<i64>
Long integer type that is a 64-bit signed number.
sourcepub fn invalid_record_count(&self) -> Option<i64>
pub fn invalid_record_count(&self) -> Option<i64>
Long integer type that is a 64-bit signed number.
sourceimpl BatchPrediction
impl BatchPrediction
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture BatchPrediction.