Struct aws_sdk_machinelearning::model::PerformanceMetrics [−][src]
Measurements of how well the MLModel performed on known observations. One of the following metrics is returned, based on the type of the MLModel:
-
BinaryAUC: The binary
MLModeluses the Area Under the Curve (AUC) technique to measure performance. -
RegressionRMSE: The regression
MLModeluses the Root Mean Square Error (RMSE) technique to measure performance. RMSE measures the difference between predicted and actual values for a single variable. -
MulticlassAvgFScore: The multiclass
MLModeluses the F1 score technique to measure performance.
For more information about performance metrics, please see the Amazon Machine Learning Developer Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.properties: Option<HashMap<String, String>>Implementations
Creates a new builder-style object to manufacture PerformanceMetrics