Struct aws_sdk_machinelearning::output::create_batch_prediction_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateBatchPredictionOutput
Implementations
A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the
BatchPredictionId in the request.
A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the
BatchPredictionId in the request.
Consumes the builder and constructs a CreateBatchPredictionOutput