Struct aws_sdk_machinelearning::output::create_data_source_from_s3_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateDataSourceFromS3Output
Implementations
A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the
DataSourceID in the request.
A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the
DataSourceID in the request.
Consumes the builder and constructs a CreateDataSourceFromS3Output