Struct aws_sdk_machinelearning::output::delete_evaluation_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeleteEvaluationOutput
Implementations
A user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
A user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
Consumes the builder and constructs a DeleteEvaluationOutput