Struct aws_sdk_machinelearning::output::get_data_source_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetDataSourceOutput
Implementations
The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The time that the DataSource was created. The time is expressed in epoch time.
The time that the DataSource was created. The time is expressed in epoch time.
The time of the most recent edit to the DataSource. The time is expressed in epoch time.
The time of the most recent edit to the DataSource. The time is expressed in epoch time.
The total size of observations in the data files.
The total size of observations in the data files.
The number of data files referenced by the DataSource.
The number of data files referenced by the DataSource.
A user-supplied name or description of the DataSource.
A user-supplied name or description of the DataSource.
The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
A link to the file containing logs of CreateDataSourceFrom* operations.
A link to the file containing logs of CreateDataSourceFrom* operations.
The user-supplied description of the most recent details about creating the DataSource.
The user-supplied description of the most recent details about creating the DataSource.
Describes the DataSource details specific to Amazon Redshift.
Describes the DataSource details specific to Amazon Redshift.
The datasource details that are specific to Amazon RDS.
The datasource details that are specific to Amazon RDS.
The Amazon Resource Name (ARN) of an AWS IAM Role, such as the following: arn:aws:iam::account:role/rolename.
The Amazon Resource Name (ARN) of an AWS IAM Role, such as the following: arn:aws:iam::account:role/rolename.
The parameter is true if statistics need to be generated from the observation data.
The parameter is true if statistics need to be generated from the observation data.
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn't available if the DataSource is in the PENDING state.
The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn't available if the DataSource is in the PENDING state.
The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
Consumes the builder and constructs a GetDataSourceOutput