Struct aws_sdk_machinelearning::output::predict_output::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for PredictOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn prediction(self, input: Prediction) -> Self
pub fn prediction(self, input: Prediction) -> Self
The output from a Predict operation:
-
Details- Contains the following attributes:DetailsAttributes.PREDICTIVE_MODEL_TYPE - REGRESSION | BINARY | MULTICLASSDetailsAttributes.ALGORITHM - SGD -
PredictedLabel- Present for either aBINARYorMULTICLASSMLModelrequest. -
PredictedScores- Contains the raw classification score corresponding to each label. -
PredictedValue- Present for aREGRESSIONMLModelrequest.
sourcepub fn set_prediction(self, input: Option<Prediction>) -> Self
pub fn set_prediction(self, input: Option<Prediction>) -> Self
The output from a Predict operation:
-
Details- Contains the following attributes:DetailsAttributes.PREDICTIVE_MODEL_TYPE - REGRESSION | BINARY | MULTICLASSDetailsAttributes.ALGORITHM - SGD -
PredictedLabel- Present for either aBINARYorMULTICLASSMLModelrequest. -
PredictedScores- Contains the raw classification score corresponding to each label. -
PredictedValue- Present for aREGRESSIONMLModelrequest.
sourcepub fn build(self) -> PredictOutput
pub fn build(self) -> PredictOutput
Consumes the builder and constructs a PredictOutput.