#[non_exhaustive]pub struct CreateBatchPredictionOutput { /* private fields */ }Expand description
Represents the output of a CreateBatchPrediction operation, and is an acknowledgement that Amazon ML received the request.
The CreateBatchPrediction operation is asynchronous. You can poll for status updates by using the >GetBatchPrediction operation and checking the Status parameter of the result.
Implementations
sourceimpl CreateBatchPredictionOutput
impl CreateBatchPredictionOutput
sourcepub fn batch_prediction_id(&self) -> Option<&str>
pub fn batch_prediction_id(&self) -> Option<&str>
A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the BatchPredictionId in the request.
sourceimpl CreateBatchPredictionOutput
impl CreateBatchPredictionOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CreateBatchPredictionOutput.