Struct aws_sdk_machinelearning::output::CreateDataSourceFromRdsOutput [−][src]
Represents the output of a CreateDataSourceFromRDS operation, and is an acknowledgement that Amazon ML received the request.
The CreateDataSourceFromRDS> operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter. You can inspect the Message when Status shows up as FAILED. You can also check the progress of the copy operation by going to the DataPipeline console and looking up the pipeline using the pipelineId from the describe call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source_id: Option<String>A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the DataSourceID in the request.
Implementations
A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the DataSourceID in the request.
Creates a new builder-style object to manufacture CreateDataSourceFromRdsOutput