Struct aws_sdk_machinelearning::output::CreateDataSourceFromS3Output [−][src]
Represents the output of a CreateDataSourceFromS3 operation, and is an acknowledgement that Amazon ML received the request.
The CreateDataSourceFromS3 operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source_id: Option<String>A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the DataSourceID in the request.
Implementations
A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the DataSourceID in the request.
Creates a new builder-style object to manufacture CreateDataSourceFromS3Output