Struct aws_sdk_machinelearning::output::CreateEvaluationOutput [−][src]
Represents the output of a CreateEvaluation operation, and is an acknowledgement that Amazon ML received the request.
CreateEvaluation operation is asynchronous. You can poll for status updates by using the GetEvcaluation operation and checking the Status parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation_id: Option<String>The user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
Implementations
The user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
Creates a new builder-style object to manufacture CreateEvaluationOutput