Struct aws_sdk_machinelearning::output::CreateMlModelOutput [−][src]
Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received the request.
The CreateMLModel operation is asynchronous. You can poll for status updates by using the GetMLModel operation and checking the Status parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ml_model_id: Option<String>A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelId in the request.
Implementations
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelId in the request.
Creates a new builder-style object to manufacture CreateMlModelOutput