#[non_exhaustive]pub struct DeleteBatchPredictionOutput { /* private fields */ }Expand description
Represents the output of a DeleteBatchPrediction operation.
You can use the GetBatchPrediction operation and check the value of the Status parameter to see whether a BatchPrediction is marked as DELETED.
Implementations
sourceimpl DeleteBatchPredictionOutput
impl DeleteBatchPredictionOutput
sourcepub fn batch_prediction_id(&self) -> Option<&str>
pub fn batch_prediction_id(&self) -> Option<&str>
A user-supplied ID that uniquely identifies the BatchPrediction. This value should be identical to the value of the BatchPredictionID in the request.
sourceimpl DeleteBatchPredictionOutput
impl DeleteBatchPredictionOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeleteBatchPredictionOutput.