#[non_exhaustive]pub struct DeleteMlModelOutput { /* private fields */ }Expand description
Represents the output of a DeleteMLModel operation.
You can use the GetMLModel operation and check the value of the Status parameter to see whether an MLModel is marked as DELETED.
Implementations
sourceimpl DeleteMlModelOutput
impl DeleteMlModelOutput
sourcepub fn ml_model_id(&self) -> Option<&str>
pub fn ml_model_id(&self) -> Option<&str>
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelID in the request.
sourceimpl DeleteMlModelOutput
impl DeleteMlModelOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeleteMlModelOutput.