#[non_exhaustive]pub struct DescribeBatchPredictionsOutput { /* private fields */ }Expand description
Represents the output of a DescribeBatchPredictions operation. The content is essentially a list of BatchPredictions.
Implementations
sourceimpl DescribeBatchPredictionsOutput
impl DescribeBatchPredictionsOutput
sourcepub fn results(&self) -> Option<&[BatchPrediction]>
pub fn results(&self) -> Option<&[BatchPrediction]>
A list of BatchPrediction objects that meet the search criteria.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The ID of the next page in the paginated results that indicates at least one more page follows.
sourceimpl DescribeBatchPredictionsOutput
impl DescribeBatchPredictionsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeBatchPredictionsOutput.