Struct aws_sdk_machinelearning::output::GetBatchPredictionOutput [−][src]
#[non_exhaustive]pub struct GetBatchPredictionOutput {Show 17 fields
pub batch_prediction_id: Option<String>,
pub ml_model_id: Option<String>,
pub batch_prediction_data_source_id: Option<String>,
pub input_data_location_s3: Option<String>,
pub created_by_iam_user: Option<String>,
pub created_at: Option<DateTime>,
pub last_updated_at: Option<DateTime>,
pub name: Option<String>,
pub status: Option<EntityStatus>,
pub output_uri: Option<String>,
pub log_uri: Option<String>,
pub message: Option<String>,
pub compute_time: Option<i64>,
pub finished_at: Option<DateTime>,
pub started_at: Option<DateTime>,
pub total_record_count: Option<i64>,
pub invalid_record_count: Option<i64>,
}Expand description
Represents the output of a GetBatchPrediction operation and describes a BatchPrediction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_prediction_id: Option<String>An ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
ml_model_id: Option<String>The ID of the MLModel that generated predictions for the BatchPrediction request.
batch_prediction_data_source_id: Option<String>The ID of the DataSource that was used to create the BatchPrediction.
input_data_location_s3: Option<String>The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
created_by_iam_user: Option<String>The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
created_at: Option<DateTime>The time when the BatchPrediction was created. The time is expressed in epoch time.
last_updated_at: Option<DateTime>The time of the most recent edit to BatchPrediction. The time is expressed in epoch time.
name: Option<String>A user-supplied name or description of the BatchPrediction.
status: Option<EntityStatus>The status of the BatchPrediction, which can be one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate batch predictions. -
INPROGRESS- The batch predictions are in progress. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
output_uri: Option<String>The location of an Amazon S3 bucket or directory to receive the operation results.
log_uri: Option<String>A link to the file that contains logs of the CreateBatchPrediction operation.
message: Option<String>A description of the most recent details about processing the batch prediction request.
compute_time: Option<i64>The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the BatchPrediction, normalized and scaled on computation resources. ComputeTime is only available if the BatchPrediction is in the COMPLETED state.
finished_at: Option<DateTime>The epoch time when Amazon Machine Learning marked the BatchPrediction as COMPLETED or FAILED. FinishedAt is only available when the BatchPrediction is in the COMPLETED or FAILED state.
started_at: Option<DateTime>The epoch time when Amazon Machine Learning marked the BatchPrediction as INPROGRESS. StartedAt isn't available if the BatchPrediction is in the PENDING state.
total_record_count: Option<i64>The number of total records that Amazon Machine Learning saw while processing the BatchPrediction.
invalid_record_count: Option<i64>The number of invalid records that Amazon Machine Learning saw while processing the BatchPrediction.
Implementations
An ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
The ID of the MLModel that generated predictions for the BatchPrediction request.
The ID of the DataSource that was used to create the BatchPrediction.
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The time when the BatchPrediction was created. The time is expressed in epoch time.
The time of the most recent edit to BatchPrediction. The time is expressed in epoch time.
The status of the BatchPrediction, which can be one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate batch predictions. -
INPROGRESS- The batch predictions are in progress. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
The location of an Amazon S3 bucket or directory to receive the operation results.
A link to the file that contains logs of the CreateBatchPrediction operation.
A description of the most recent details about processing the batch prediction request.
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the BatchPrediction, normalized and scaled on computation resources. ComputeTime is only available if the BatchPrediction is in the COMPLETED state.
The epoch time when Amazon Machine Learning marked the BatchPrediction as COMPLETED or FAILED. FinishedAt is only available when the BatchPrediction is in the COMPLETED or FAILED state.
The epoch time when Amazon Machine Learning marked the BatchPrediction as INPROGRESS. StartedAt isn't available if the BatchPrediction is in the PENDING state.
The number of total records that Amazon Machine Learning saw while processing the BatchPrediction.
The number of invalid records that Amazon Machine Learning saw while processing the BatchPrediction.
Creates a new builder-style object to manufacture GetBatchPredictionOutput