#[non_exhaustive]pub struct GetDataSourceOutput { /* private fields */ }Expand description
Represents the output of a GetDataSource operation and describes a DataSource.
Implementations
sourceimpl GetDataSourceOutput
impl GetDataSourceOutput
sourcepub fn data_source_id(&self) -> Option<&str>
pub fn data_source_id(&self) -> Option<&str>
The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
sourcepub fn data_location_s3(&self) -> Option<&str>
pub fn data_location_s3(&self) -> Option<&str>
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
sourcepub fn data_rearrangement(&self) -> Option<&str>
pub fn data_rearrangement(&self) -> Option<&str>
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
sourcepub fn created_by_iam_user(&self) -> Option<&str>
pub fn created_by_iam_user(&self) -> Option<&str>
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The time that the DataSource was created. The time is expressed in epoch time.
sourcepub fn last_updated_at(&self) -> Option<&DateTime>
pub fn last_updated_at(&self) -> Option<&DateTime>
The time of the most recent edit to the DataSource. The time is expressed in epoch time.
sourcepub fn data_size_in_bytes(&self) -> Option<i64>
pub fn data_size_in_bytes(&self) -> Option<i64>
The total size of observations in the data files.
sourcepub fn number_of_files(&self) -> Option<i64>
pub fn number_of_files(&self) -> Option<i64>
The number of data files referenced by the DataSource.
sourcepub fn status(&self) -> Option<&EntityStatus>
pub fn status(&self) -> Option<&EntityStatus>
The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
sourcepub fn log_uri(&self) -> Option<&str>
pub fn log_uri(&self) -> Option<&str>
A link to the file containing logs of CreateDataSourceFrom* operations.
sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
The user-supplied description of the most recent details about creating the DataSource.
sourcepub fn redshift_metadata(&self) -> Option<&RedshiftMetadata>
pub fn redshift_metadata(&self) -> Option<&RedshiftMetadata>
Describes the DataSource details specific to Amazon Redshift.
sourcepub fn rds_metadata(&self) -> Option<&RdsMetadata>
pub fn rds_metadata(&self) -> Option<&RdsMetadata>
The datasource details that are specific to Amazon RDS.
sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of an AWS IAM Role, such as the following: arn:aws:iam::account:role/rolename.
sourcepub fn compute_statistics(&self) -> bool
pub fn compute_statistics(&self) -> bool
The parameter is true if statistics need to be generated from the observation data.
sourcepub fn compute_time(&self) -> Option<i64>
pub fn compute_time(&self) -> Option<i64>
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
sourcepub fn finished_at(&self) -> Option<&DateTime>
pub fn finished_at(&self) -> Option<&DateTime>
The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
sourcepub fn started_at(&self) -> Option<&DateTime>
pub fn started_at(&self) -> Option<&DateTime>
The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn't available if the DataSource is in the PENDING state.
sourcepub fn data_source_schema(&self) -> Option<&str>
pub fn data_source_schema(&self) -> Option<&str>
The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
sourceimpl GetDataSourceOutput
impl GetDataSourceOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GetDataSourceOutput.