Struct aws_sdk_machinelearning::output::UpdateBatchPredictionOutput [−][src]
#[non_exhaustive]pub struct UpdateBatchPredictionOutput {
pub batch_prediction_id: Option<String>,
}Expand description
Represents the output of an UpdateBatchPrediction operation.
You can see the updated content by using the GetBatchPrediction operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_prediction_id: Option<String>The ID assigned to the BatchPrediction during creation. This value should be identical to the value of the BatchPredictionId in the request.
Implementations
The ID assigned to the BatchPrediction during creation. This value should be identical to the value of the BatchPredictionId in the request.
Creates a new builder-style object to manufacture UpdateBatchPredictionOutput