Struct aws_sdk_machinelearning::output::UpdateDataSourceOutput [−][src]
Represents the output of an UpdateDataSource operation.
You can see the updated content by using the GetBatchPrediction operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source_id: Option<String>The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
Implementations
The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
Creates a new builder-style object to manufacture UpdateDataSourceOutput