Struct aws_sdk_machinelearning::output::UpdateEvaluationOutput [−][src]
Represents the output of an UpdateEvaluation operation.
You can see the updated content by using the GetEvaluation operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation_id: Option<String>The ID assigned to the Evaluation during creation. This value should be identical to the value of the Evaluation in the request.
Implementations
The ID assigned to the Evaluation during creation. This value should be identical to the value of the Evaluation in the request.
Creates a new builder-style object to manufacture UpdateEvaluationOutput