Struct aws_sdk_machinelearning::output::UpdateMlModelOutput [−][src]
Represents the output of an UpdateMLModel operation.
You can see the updated content by using the GetMLModel operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ml_model_id: Option<String>The ID assigned to the MLModel during creation. This value should be identical to the value of the MLModelID in the request.
Implementations
The ID assigned to the MLModel during creation. This value should be identical to the value of the MLModelID in the request.
Creates a new builder-style object to manufacture UpdateMlModelOutput