Struct aws_sdk_machinelearning::output::update_data_source_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateDataSourceOutput
Implementations
The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
Consumes the builder and constructs a UpdateDataSourceOutput