Struct aws_sdk_machinelearning::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for AmazonML_20141212.
This client allows ergonomic access to a AmazonML_20141212-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AddTags operation.
See AddTags for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateBatchPrediction operation.
See CreateBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromRDS operation.
See CreateDataSourceFromRDS for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromRedshift operation.
See CreateDataSourceFromRedshift for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSourceFromS3 operation.
See CreateDataSourceFromS3 for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateEvaluation operation.
See CreateEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateMLModel operation.
See CreateMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateRealtimeEndpoint operation.
See CreateRealtimeEndpoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBatchPrediction operation.
See DeleteBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDataSource operation.
See DeleteDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteEvaluation operation.
See DeleteEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteMLModel operation.
See DeleteMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteRealtimeEndpoint operation.
See DeleteRealtimeEndpoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteTags operation.
See DeleteTags for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeBatchPredictions operation.
See DescribeBatchPredictions for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeDataSources operation.
See DescribeDataSources for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeEvaluations operation.
See DescribeEvaluations for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeMLModels operation.
See DescribeMLModels for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeTags operation.
See DescribeTags for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBatchPrediction operation.
See GetBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the GetDataSource operation.
See GetDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the GetEvaluation operation.
See GetEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the GetMLModel operation.
See GetMLModel for more information about the
operation and its arguments.
Constructs a fluent builder for the Predict operation.
See Predict for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateBatchPrediction operation.
See UpdateBatchPrediction for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDataSource operation.
See UpdateDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateEvaluation operation.
See UpdateEvaluation for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateMLModel operation.
See UpdateMLModel for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.