Module aws_sdk_machinelearning::error
source · Expand description
All error types that operations can return. Documentation on these types is copied from the model.
Modules
Structs
Error type for the
AddTags operation.Error type for the
CreateBatchPrediction operation.Error type for the
CreateDataSourceFromRDS operation.Error type for the
CreateDataSourceFromRedshift operation.Error type for the
CreateDataSourceFromS3 operation.Error type for the
CreateEvaluation operation.Error type for the
CreateMLModel operation.Error type for the
CreateRealtimeEndpoint operation.Error type for the
DeleteBatchPrediction operation.Error type for the
DeleteDataSource operation.Error type for the
DeleteEvaluation operation.Error type for the
DeleteMLModel operation.Error type for the
DeleteRealtimeEndpoint operation.Error type for the
DeleteTags operation.Error type for the
DescribeBatchPredictions operation.Error type for the
DescribeDataSources operation.Error type for the
DescribeEvaluations operation.Error type for the
DescribeMLModels operation.Error type for the
DescribeTags operation.Error type for the
GetBatchPrediction operation.Error type for the
GetDataSource operation.Error type for the
GetEvaluation operation.Error type for the
GetMLModel operation.A second request to use or change an object was not allowed. This can result from retrying a request using a parameter that was not present in the original request.
An error on the server occurred when trying to process a request.
An error on the client occurred. Typically, the cause is an invalid input value.
The subscriber exceeded the maximum number of operations. This exception can occur when listing objects such as DataSource.
Error type for the
Predict operation.The exception is thrown when a predict request is made to an unmounted MLModel.
A specified resource cannot be located.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Error type for the
UpdateBatchPrediction operation.Error type for the
UpdateDataSource operation.Error type for the
UpdateEvaluation operation.Error type for the
UpdateMLModel operation.Enums
Types of errors that can occur for the
AddTags operation.Types of errors that can occur for the
CreateBatchPrediction operation.Types of errors that can occur for the
CreateDataSourceFromRDS operation.Types of errors that can occur for the
CreateDataSourceFromRedshift operation.Types of errors that can occur for the
CreateDataSourceFromS3 operation.Types of errors that can occur for the
CreateEvaluation operation.Types of errors that can occur for the
CreateMLModel operation.Types of errors that can occur for the
CreateRealtimeEndpoint operation.Types of errors that can occur for the
DeleteBatchPrediction operation.Types of errors that can occur for the
DeleteDataSource operation.Types of errors that can occur for the
DeleteEvaluation operation.Types of errors that can occur for the
DeleteMLModel operation.Types of errors that can occur for the
DeleteRealtimeEndpoint operation.Types of errors that can occur for the
DeleteTags operation.Types of errors that can occur for the
DescribeBatchPredictions operation.Types of errors that can occur for the
DescribeDataSources operation.Types of errors that can occur for the
DescribeEvaluations operation.Types of errors that can occur for the
DescribeMLModels operation.Types of errors that can occur for the
DescribeTags operation.Types of errors that can occur for the
GetBatchPrediction operation.Types of errors that can occur for the
GetDataSource operation.Types of errors that can occur for the
GetEvaluation operation.Types of errors that can occur for the
GetMLModel operation.Types of errors that can occur for the
Predict operation.Types of errors that can occur for the
UpdateBatchPrediction operation.Types of errors that can occur for the
UpdateDataSource operation.Types of errors that can occur for the
UpdateEvaluation operation.Types of errors that can occur for the
UpdateMLModel operation.