Struct aws_sdk_machinelearning::input::update_ml_model_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateMlModelInput
Implementations
The ID assigned to the MLModel during creation.
The ID assigned to the MLModel during creation.
A user-supplied name or description of the MLModel.
A user-supplied name or description of the MLModel.
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
Consumes the builder and constructs a UpdateMlModelInput