Module aws_sdk_machinelearning::model
source · Expand description
Data structures used by operation inputs/outputs. Documentation on these types is copied from the model.
Modules
Evaluation.Prediction.Structs
Represents the output of a GetBatchPrediction operation.
Represents the output of the GetDataSource operation.
Represents the output of GetEvaluation operation.
Represents the output of a GetMLModel operation.
Measurements of how well the MLModel performed on known observations. One of the following metrics is returned, based on the type of the MLModel:
The output from a Predict operation:
The data specification of an Amazon Relational Database Service (Amazon RDS) DataSource.
The database details of an Amazon RDS database.
The database credentials to connect to a database on an RDS DB instance.
The datasource details that are specific to Amazon RDS.
Describes the real-time endpoint information for an MLModel.
Describes the data specification of an Amazon Redshift DataSource.
Describes the database details required to connect to an Amazon Redshift database.
Describes the database credentials for connecting to a database on an Amazon Redshift cluster.
Describes the DataSource details specific to Amazon Redshift.
Describes the data specification of a DataSource.
A custom key-value pair associated with an ML object, such as an ML model.
Enums
Algorithm, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.BatchPredictionFilterVariable, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.DataSourceFilterVariable, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.DetailsAttributes, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.EntityStatus, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.EvaluationFilterVariable, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.MlModelFilterVariable, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.MlModelType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.RealtimeEndpointStatus, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.SortOrder, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.TaggableResourceType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.