Enum aws_sdk_machinelearning::model::EvaluationFilterVariable [−][src]
#[non_exhaustive]
pub enum EvaluationFilterVariable {
CreatedAt,
DatasourceId,
DataUri,
IamUser,
LastUpdatedAt,
MlModelId,
Name,
Status,
Unknown(String),
}Expand description
A list of the variables to use in searching or filtering Evaluation.
-
CreatedAt- Sets the search criteria toEvaluationcreation date. -
Status- Sets the search criteria toEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked an evaluation. -
MLModelId- Sets the search criteria to thePredictorthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused in evaluation. -
DataUri- Sets the search criteria to the data file(s) used in evaluation. The URL can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CreatedAt
DatasourceId
DataUri
IamUser
LastUpdatedAt
MlModelId
Name
Status
Unknown(String)
Tuple Fields
0: StringUnknown contains new variants that have been added since this code was generated.
Implementations