Struct aws_sdk_machinelearning::output::predict_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PredictOutput
Implementations
The output from a Predict operation:
-
Details- Contains the following attributes:DetailsAttributes.PREDICTIVE_MODEL_TYPE - REGRESSION | BINARY | MULTICLASSDetailsAttributes.ALGORITHM - SGD -
PredictedLabel- Present for either aBINARYorMULTICLASSMLModelrequest. -
PredictedScores- Contains the raw classification score corresponding to each label. -
PredictedValue- Present for aREGRESSIONMLModelrequest.
The output from a Predict operation:
-
Details- Contains the following attributes:DetailsAttributes.PREDICTIVE_MODEL_TYPE - REGRESSION | BINARY | MULTICLASSDetailsAttributes.ALGORITHM - SGD -
PredictedLabel- Present for either aBINARYorMULTICLASSMLModelrequest. -
PredictedScores- Contains the raw classification score corresponding to each label. -
PredictedValue- Present for aREGRESSIONMLModelrequest.
Consumes the builder and constructs a PredictOutput