Struct aws_sdk_machinelearning::output::CreateBatchPredictionOutput [−][src]
#[non_exhaustive]pub struct CreateBatchPredictionOutput {
pub batch_prediction_id: Option<String>,
}Expand description
Represents the output of a CreateBatchPrediction operation, and is an acknowledgement that Amazon ML received the request.
The CreateBatchPrediction operation is asynchronous. You can poll for status updates by using the >GetBatchPrediction operation and checking the Status parameter of the result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_prediction_id: Option<String>A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the BatchPredictionId in the request.
Implementations
A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the BatchPredictionId in the request.
Creates a new builder-style object to manufacture CreateBatchPredictionOutput