Struct aws_sdk_machinelearning::output::DeleteBatchPredictionOutput [−][src]
#[non_exhaustive]pub struct DeleteBatchPredictionOutput {
pub batch_prediction_id: Option<String>,
}Expand description
Represents the output of a DeleteBatchPrediction operation.
You can use the GetBatchPrediction operation and check the value of the Status parameter to see whether a BatchPrediction is marked as DELETED.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_prediction_id: Option<String>A user-supplied ID that uniquely identifies the BatchPrediction. This value should be identical to the value of the BatchPredictionID in the request.
Implementations
A user-supplied ID that uniquely identifies the BatchPrediction. This value should be identical to the value of the BatchPredictionID in the request.
Creates a new builder-style object to manufacture DeleteBatchPredictionOutput