Struct aws_sdk_machinelearning::output::DeleteMlModelOutput [−][src]
Represents the output of a DeleteMLModel operation.
You can use the GetMLModel operation and check the value of the Status parameter to see whether an MLModel is marked as DELETED.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ml_model_id: Option<String>A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelID in the request.
Implementations
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelID in the request.
Creates a new builder-style object to manufacture DeleteMlModelOutput