Struct aws_sdk_machinelearning::output::GetDataSourceOutput [−][src]
#[non_exhaustive]pub struct GetDataSourceOutput {Show 20 fields
pub data_source_id: Option<String>,
pub data_location_s3: Option<String>,
pub data_rearrangement: Option<String>,
pub created_by_iam_user: Option<String>,
pub created_at: Option<DateTime>,
pub last_updated_at: Option<DateTime>,
pub data_size_in_bytes: Option<i64>,
pub number_of_files: Option<i64>,
pub name: Option<String>,
pub status: Option<EntityStatus>,
pub log_uri: Option<String>,
pub message: Option<String>,
pub redshift_metadata: Option<RedshiftMetadata>,
pub rds_metadata: Option<RdsMetadata>,
pub role_arn: Option<String>,
pub compute_statistics: bool,
pub compute_time: Option<i64>,
pub finished_at: Option<DateTime>,
pub started_at: Option<DateTime>,
pub data_source_schema: Option<String>,
}Expand description
Represents the output of a GetDataSource operation and describes a DataSource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source_id: Option<String>The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
data_location_s3: Option<String>The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
data_rearrangement: Option<String>A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
created_by_iam_user: Option<String>The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
created_at: Option<DateTime>The time that the DataSource was created. The time is expressed in epoch time.
last_updated_at: Option<DateTime>The time of the most recent edit to the DataSource. The time is expressed in epoch time.
data_size_in_bytes: Option<i64>The total size of observations in the data files.
number_of_files: Option<i64>The number of data files referenced by the DataSource.
name: Option<String>A user-supplied name or description of the DataSource.
status: Option<EntityStatus>The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
log_uri: Option<String>A link to the file containing logs of CreateDataSourceFrom* operations.
message: Option<String>The user-supplied description of the most recent details about creating the DataSource.
redshift_metadata: Option<RedshiftMetadata>Describes the DataSource details specific to Amazon Redshift.
rds_metadata: Option<RdsMetadata>The datasource details that are specific to Amazon RDS.
role_arn: Option<String>The Amazon Resource Name (ARN) of an AWS IAM Role, such as the following: arn:aws:iam::account:role/rolename.
compute_statistics: bool The parameter is true if statistics need to be generated from the observation data.
compute_time: Option<i64>The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
finished_at: Option<DateTime>The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
started_at: Option<DateTime>The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn't available if the DataSource is in the PENDING state.
data_source_schema: Option<String>The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
Implementations
The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
The time that the DataSource was created. The time is expressed in epoch time.
The time of the most recent edit to the DataSource. The time is expressed in epoch time.
The total size of observations in the data files.
The number of data files referenced by the DataSource.
The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
A link to the file containing logs of CreateDataSourceFrom* operations.
The user-supplied description of the most recent details about creating the DataSource.
Describes the DataSource details specific to Amazon Redshift.
The datasource details that are specific to Amazon RDS.
The Amazon Resource Name (ARN) of an AWS IAM Role, such as the following: arn:aws:iam::account:role/rolename.
The parameter is true if statistics need to be generated from the observation data.
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn't available if the DataSource is in the PENDING state.
The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
Creates a new builder-style object to manufacture GetDataSourceOutput